Throws constructor

const Throws(
  1. Set<Type> exceptions
)

Creates a Throws annotation with the given set of exception types.

The exceptions parameter should contain the types of exceptions that the annotated declaration may throw.

Implementation

const Throws(this.exceptions);