DartAnnotationsPlugin class final
The annotations analyzer plugin.
This plugin provides static analysis rules for annotations defined in the dart_annotations package, such as @Throws.
- Inheritance
-
- Object
- Plugin
- DartAnnotationsPlugin
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginRegistry registry) → void -
Registers analysis rules, quick fixes, and assists.
override
-
shutDown(
) → FutureOr< void> -
inherited
-
start(
) → FutureOr< void> -
Initializes any necessary start-up state that is required for this plugin
to run.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited