plugin top-level property
The plugin instance that the analysis server looks for.
This MUST be a top-level variable named plugin.
Implementation
final plugin = DartAnnotationsPlugin();
The plugin instance that the analysis server looks for.
This MUST be a top-level variable named plugin.
final plugin = DartAnnotationsPlugin();