Creates a Throws annotation with the given set of exception types.
The exceptions parameter should contain the types of exceptions that the annotated declaration may throw.
exceptions
const Throws(this.exceptions);